﻿Public Class Form1
    Enum Run_Step As Integer
        LA_Not_Initialize
        LA_Standby
        LA_Capturing
    End Enum


    'Member variables
    Dim m_iStep As Run_Step = Run_Step.LA_Not_Initialize
    Dim m_LATrig As New LaSDK_Class.TRIG
    Dim m_fHasData As Boolean = False
    Dim m_WaveData As UInt32()



    Private Sub Form1_Load(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles MyBase.Load
        'Initilize the Trig Structure
        m_LATrig.Initialize()
        EnableUIControl()
    End Sub

    Private Sub bnInit_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles bnInit.Click
        If (LaSDK_Class.ulaSDKInit()) Then
            m_iStep = Run_Step.LA_Standby
            m_fHasData = False

            Dim iLaID As Integer = LaSDK_Class.ulaSDKGetLaID()
            Dim i As Integer = 0
            While (LaSDK_Class.m_InfoLst(i).wID <> 0)
                If (LaSDK_Class.m_InfoLst(i).wID = iLaID) Then
                    lbModel.Text = LaSDK_Class.m_InfoLst(i).pName
                    Exit While
                Else
                    i += 1
                End If
            End While

        End If
        EnableUIControl()
    End Sub
    Private Sub bnCapture_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles bnCapture.Click
        'Set LA Hardware mode to 200M - 9Channel
        LaSDK_Class.ulaSDKSetHwInfo(LaSDK_Class.SET_TL_MODE, LaSDK_Class.LA_HW_MODE.HW_200M_9CH)

        'Set to maximum record length
        Dim iRecLength As Integer = LaSDK_Class.ulaSDKGetMaxSamplesNum()
        LaSDK_Class.ulaSDKSetSamplesNum(iRecLength)

        'Set Threshold to 1.6V
        LaSDK_Class.ulaSDKThreshold(0, 1600)

        'Clear Trigger Structure
        LaSDK_Class.ulaSDKClearTrigger(m_LATrig)

        'Set Trigger to Ch0 Rising edge, Single trigger
        Dim iTrigCh As Integer = 0
        Dim iTrigLevel As Integer = 0
        Dim iTrigEdge As Integer = LaSDK_Class.LA_TRIG_CHANGE
        LaSDK_Class.ulaSDKSetChTrigger(m_LATrig, iTrigLevel, iTrigCh, iTrigEdge, LaSDK_Class.TR_CONTINUE)

        'Other Parameters
        m_LATrig.iFreq = 200000000  'Sample Rate
        m_LATrig.iFreqHi = 0

        m_LATrig.iTrPos = 100       'Trigger Position

        m_LATrig.iFlag = LaSDK_Class.TR_PRETRIG 'Enable Pre-Trigger


        If (LaSDK_Class.ulaSDKCapture(m_LATrig)) Then
            m_iStep = Run_Step.LA_Capturing
            Timer1.Start()
        End If
        EnableUIControl()
    End Sub
    Private Sub bnShutdown_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles bnShutdown.Click
        If (LaSDK_Class.ulaSDKClose()) Then
            m_iStep = Run_Step.LA_Not_Initialize
            lbModel.Text = "Demo"
        End If
        EnableUIControl()
    End Sub

    Private Sub bnSaveLaw_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles bnSaveLaw.Click
        Dim fd As SaveFileDialog = New SaveFileDialog()

        fd.Title = "Save waveform to .LAW file..."
        fd.InitialDirectory = "C:\"
        fd.Filter = "LAW files (*.law)|*.law"
        fd.FilterIndex = 1
        fd.RestoreDirectory = True

        If fd.ShowDialog() = DialogResult.OK Then
            LaSDK_Class.ulaSDKSaveAsLawFile(fd.FileName)
        End If

    End Sub

    Private Sub bnStop_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles bnStop.Click
        If (LaSDK_Class.ulaSDKStopCapture()) Then
            m_iStep = Run_Step.LA_Standby
            Timer1.Stop()
        End If
        EnableUIControl()
    End Sub

    Private Sub bnClose_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles bnClose.Click
        Me.Close()
    End Sub

    Private Sub EnableUIControl()
        bnInit.Enabled = (m_iStep = Run_Step.LA_Not_Initialize)
        bnCapture.Enabled = (m_iStep = Run_Step.LA_Standby)
        bnStop.Enabled = (m_iStep = Run_Step.LA_Capturing)
        bnShutdown.Enabled = (m_iStep = Run_Step.LA_Standby)
        bnSaveLaw.Enabled = m_fHasData
    End Sub

    Private Sub ReadDataFromLA()
        Dim iMSB As Integer = 8 'MSB = Channel 8
        Dim iLSB As Integer = 0 'LSB = Channel 0
        Dim iSize As Integer = LaSDK_Class.ulaSDKGetSamplesNum()
        Dim iStartReadFrom As Integer = 0   'Read From point 0
        ReDim m_WaveData(iSize)

        If (LaSDK_Class.ulaSDKGetBusData(iMSB, iLSB, m_WaveData, iSize, iStartReadFrom)) Then
            m_fHasData = True
            Me.Invalidate()
        End If
        m_iStep = Run_Step.LA_Standby
        EnableUIControl()
    End Sub

    Private Sub Timer1_Tick(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles Timer1.Tick
        If (LaSDK_Class.ulaSDKIsCaptureReady()) Then
            Timer1.Stop()
            ReadDataFromLA()
        End If
    End Sub

    Private Sub Form1_Paint(ByVal sender As System.Object, ByVal e As System.Windows.Forms.PaintEventArgs) Handles MyBase.Paint
        'This Demo paint event only shows the first X points of the sampled waveform
        Dim rcCanvas As System.Drawing.Rectangle = Me.RectangleToClient(panelWaveform.RectangleToScreen(panelWaveform.ClientRectangle))
        Dim iWaveHeight As Integer = (rcCanvas.Height - 2) / 9
        Dim ptWave As System.Drawing.Point()
        Dim iChPos As Integer
        Dim iSigHighPos As Integer
        Dim iSigLowPos As Integer

        ReDim ptWave(rcCanvas.Width)

        e.Graphics.DrawRectangle(Pens.Gray, rcCanvas)
        If (m_fHasData) Then
            For iCh As Integer = 0 To 9
                iChPos = rcCanvas.Top + 1 + iWaveHeight * iCh
                iSigHighPos = iChPos + 1
                iSigLowPos = iChPos + iWaveHeight - 1
                For iSample As Integer = 0 To rcCanvas.Width
                    ptWave(iSample).X = iSample + rcCanvas.Left
                    If (m_WaveData(iSample) And (1 << iCh)) Then
                        ptWave(iSample).Y = iSigHighPos
                    Else
                        ptWave(iSample).Y = iSigLowPos
                    End If
                Next
                e.Graphics.DrawLines(Pens.Black, ptWave)
            Next
        End If

        'e.Graphics.DrawLine(Pens.Black, rcCanvas.Left, rcCanvas.Top, rcCanvas.Right, rcCanvas.Bottom)
    End Sub

    Private Sub Form1_FormClosed(ByVal sender As System.Object, ByVal e As System.Windows.Forms.FormClosedEventArgs) Handles MyBase.FormClosed
        LaSDK_Class.ulaSDKClose()
    End Sub
End Class
